transformer.GRS1Transformer

|  | ## Cheshire3 Object Model: Class GRS1Transformer

Module transformer :: Class GRS1Transformer

## Class GRS1Transformer
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
      baseObjects.Transformer --+
                                |
                               GRS1Transformer

Create representation of the XML tree in Z39.50's GRS1 format
Instance Methods

initState(self)
startElement(self, name, attribs)
endElement(self, foo)
characters(self, text, zero, length)
process_record(self, session, rec) Take a Record, transform it and return a new Document object.
Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### initState(self) | source code

### startElement(self, name, attribs) | source code

### endElement(self, foo) | source code

### characters(self, text, zero, length) | source code

### process_record(self, session, rec) | source code
Take a Record, transform it and return a new Document object. Overrides: baseObjects.Transformer.process_record (inherited documentation)